# spindynamics
Spin dynamics package.

| Description   | Badge                                                                                                                                                                         |
|---------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| Tests         | [![Test package](https://github.com/MaMMoS-project/mammos-units/actions/workflows/test.yml/badge.svg)](https://github.com/MaMMoS-project/mammos-units/actions/workflows/test.yml) |
| Linting       | [![pre-commit.ci status](https://results.pre-commit.ci/badge/github/mammos-project/mammos-mumag/main.svg)](https://results.pre-commit.ci/latest/github/mammos-project/mammos-units/main)                                                                                                                                                                          |
| Releases      | [![PyPI version](https://badge.fury.io/py/mammos-units.svg)](https://badge.fury.io/py/mammos-units)                                                                               |
| Documentation | [![Documentation](https://img.shields.io/badge/Docs-mammos--project.github.io%2Fmammos-blue)](https://mammos-project.github.io/mammos/index.html)                                                                                                                            |
| Binder        | [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/mammos-project/mammos-spindynamics/main?urlpath=lab%2Ftree%2Fexamples)                                                                   |
| License       | [![License](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)                                                                                                                                                                              |
| DOI           | TODO                                                                                                                                                                          |


## Try it in the cloud
Try `mammos-spindynamics` without installing it locally by directly accessing it directly in the cloud
via Binder.

Simply click the badge in the table above to get started.

## Documentation

APIs and tutorials are available in the documentation. To access the documentation, use the badge in the table above.

## Installation

To install `mammos-spindynamics`, you can use `pip install mammos-spindynamics` inside a Python virtual environment.
For more details refer to the documentation.

## How to cite

TODO

## Acknowledgements

This software has been supported by the European Union’s Horizon Europe research and innovation programme under grant agreement No 101135546 [MaMMoS](https://mammos-project.github.io/).
